| get_stats | R Documentation |
This daily chart exhibits the descriptive statistics of price, rate and price variation from securities in the Bolivian Securities Exchange.
get_stats(data)
data |
A defined variable storing the daily data from the import_data function. |
MEAN |
This row displays the mean calculations of today's prices, rates, and price variations of all traded securities. |
MEDIAN |
This row displays the median calculations of today's prices, rates, and price variations of all traded securities. |
ST. DEV. |
This row displays the standard deviation calculations of today's prices, rates, and price variations of all traded securities. |
MIN. |
This row displays the minimum value of today's prices, rates, and price variations of all traded securities. |
MAX. |
This row displays the maximum value of today's prices, rates, and price variations of all traded securities. |
Alvaro Ignacio Tapia
The Bolivian Stock Exchange (Bolsa Boliviana de Valores), based in La Paz, Bolivia, offers trading of equities, indexes, gold, and local commodities.
data <- import_data()
get_stats(data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.