| import_data | R Documentation |
Primary function that imports daily data of securities presenting the highest and lowest price variations in the Bolivian Securities Exchange.
import_data(verbose = TRUE)
verbose |
Logical. If |
TICKER SYMBOL |
This column lists the code names of each traded security. |
ISSUER NAME |
This column lists the company names that issue each traded security. |
PRICE |
This column lists today's prices of each traded security. |
RATE |
This column lists the percentage interest rate of each traded security. |
VAR. |
This column lists the price variations between yesterday and today for each traded security. |
The function returns a data frame with the above columns. If no data is available, the function returns NULL.
Alvaro Ignacio Tapia
The Bolivian Stock Exchange (Bolsa Boliviana de Valores), based in La Paz, Bolivia, offers trading of equities, indexes, gold, and local commodities.
# Import market data
data <- import_data()
head(data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.